import { ConfigProviderProps, MappingAlgorithm, ThemeConfig } from 'antd';
import { ComponentToken as TableComponentToken } from 'antd/es/table/style';
import { AliasToken } from 'antd/es/theme/internal';
import { ComponentTokenMap } from 'antd/lib/theme/interface/components';
import { FC } from 'react';
/** 给ant table组件添加design token */
export interface BitzTableComponentToken extends TableComponentToken {
    toolbarBgColor?: string;
    evenRowBgColor?: string;
    expandIconBorderColor?: string;
    mobileListBgColor?: string;
    listItemBgColor?: string;
}
/** 增强ComponentTokenMap Table属性的类型 */
export interface BitzComponentTokenMap extends Omit<ComponentTokenMap, 'Table'> {
    Table: BitzTableComponentToken;
}
type OverrideToken = {
    [key in keyof BitzComponentTokenMap]: Partial<BitzComponentTokenMap[key]> & Partial<AliasToken>;
};
type ComponentsConfig = {
    [key in keyof OverrideToken]?: OverrideToken[key] & {
        algorithm?: boolean | MappingAlgorithm | MappingAlgorithm[];
    };
};
/** 给ant添加全局design token */
export interface BitzAliasToken extends AliasToken {
    colorTextHover: string;
    colorTextActive: string;
    colorSecondaryHighlightText: string;
}
/** 增强ThemeConfig的token和components属性的类型 */
export interface BitzThemeConfigProps extends Omit<ThemeConfig, 'token' | 'components'> {
    token?: Partial<BitzAliasToken>;
    components?: ComponentsConfig;
}
/** BitzConfigProviderProps组件类型 */
export interface BitzConfigProviderProps extends Omit<ConfigProviderProps, 'theme'> {
    theme?: BitzThemeConfigProps;
}
/** BitzConfigProvider全局化配置 */
declare const BitzConfigProvider: FC<BitzConfigProviderProps>;
export default BitzConfigProvider;
