/// <reference types="react" />
import BitzHighlightChild from './Child';
/**
 * 高亮文本类型
 * @primary 高亮文本主题色，非高亮文本默认黑色
 * @secondary 高亮文本黑色，非高亮文本默认灰色
 */
type HighlightType = 'primary' | 'secondary' | undefined;
/** Highlight属性 */
interface BitzHighlightProps {
    /** 是否启用转义 */
    autoEscape?: boolean;
    /** 是否启用大小写转换 */
    caseSensitive?: boolean;
    /** 文本级别类型 */
    type?: HighlightType;
    /** 源文本 */
    sourceString: string;
    /** 期望被高亮的文本 */
    keywords: string | string[];
    /** 根节点对应的 HTML 标签名 */
    tag?: keyof HTMLElementTagNameMap;
    /** 根节点的类名 */
    tagClass?: string;
    /** 高亮文本元素的 HTML 标签名 */
    highlightTag?: keyof HTMLElementTagNameMap;
    /** 高亮元素的类名 */
    highlightClass?: string;
    /** 非高亮元素对应的 HTML 标签名 */
    unhighlightTag?: keyof HTMLElementTagNameMap;
    /** 非高亮元素的类名 */
    unhighlightClass?: string;
}
/** Highlight Child属性 */
type BitzHighlightChildProps = Omit<BitzHighlightProps, 'type' | 'tag' | 'tagClass' | 'highlightTag' | 'unhighlightTag'>;
type CompoundedComponent = React.ForwardRefExoticComponent<BitzHighlightProps> & {
    Child: typeof BitzHighlightChild;
};
declare const BitzHighlight: CompoundedComponent;
export type { HighlightType, BitzHighlightProps, BitzHighlightChildProps };
export default BitzHighlight;
