/// <reference types="react" />
import { TableColumnType } from 'antd';
export type DensitySize = 'xl' | 'lg' | 'md' | 'sm' | 'xs' | undefined;
export type ColumnsState = {
    show?: boolean;
    fixed?: 'right' | 'left' | undefined;
    order?: number;
    disable?: boolean | {
        checkbox: boolean;
    };
};
export type ColumnStateType = {
    /**
     * 持久化的类型，支持 localStorage 和 sessionStorage
     *
     * @param localStorage 设置在关闭浏览器后也是存在的
     * @param sessionStorage 关闭浏览器后会丢失
     */
    persistenceType?: 'localStorage' | 'sessionStorage' | 'online';
    /** 持久化的key，用于存储到 storage 中 */
    persistenceKey?: string;
    /** ColumnsState 的值，columnsStateMap将会废弃 */
    defaultValue?: Record<string, ColumnsState>;
    /** ColumnsState 的值，columnsStateMap将会废弃 */
    value?: Record<string, ColumnsState>;
    onChange?: (map: Record<string, ColumnsState>) => void;
    /** 仅在 persistenceType=online 有效 用于数据修改后数据上报  */
    onlineChange?: (key: string, ColumnsState: Record<string, ColumnsState>) => void;
    /** 仅在 persistenceType=online 有效 用于获取网络数据 */
    onlineGet?: (key: string) => Promise<Record<string, ColumnsState> | null | undefined>;
};
export type ProTableColumn<T> = ColumnsState & TableColumnType<T>;
export type UseContainerProps<T = any> = {
    columnsStateMap?: Record<string, ColumnsState>;
    onColumnsStateChange?: (map: Record<string, ColumnsState>) => void;
    size?: DensitySize;
    defaultSize?: DensitySize;
    onSizeChange?: (size: DensitySize) => void;
    columns?: ProTableColumn<T>[];
    columnsState?: ColumnStateType;
    /** 仅在 persistenceType=online 有效 用于数据修改后数据上报  */
    onlineChange?: (key: string, ColumnsState: ColumnsState) => void;
    /** 持久化的key，用于存储到 storage 中 */
    persistenceKey?: string;
};
declare function useContainer(props?: UseContainerProps): {
    uuid: string;
    persistenceType: "online" | "localStorage" | "sessionStorage" | undefined;
    persistenceKey: string | undefined;
    onlineChange: ((key: string, ColumnsState: Record<string, ColumnsState>) => void) | undefined;
    sortKeyColumns: string[];
    setSortKeyColumns: (keys: string[]) => void;
    columnsMap: Record<string, ColumnsState>;
    setColumnsMap: (updater: Record<string, ColumnsState> | ((origin: Record<string, ColumnsState>) => Record<string, ColumnsState>), ignoreDestroy?: boolean | undefined) => void;
    setTableSize: (updater: DensitySize | ((origin: DensitySize) => DensitySize), ignoreDestroy?: boolean | undefined) => void;
    tableSize: DensitySize;
    columns: ProTableColumn<any>[] | undefined;
    clearPersistenceStorage: () => void;
    defaultColumnKeyMap: Record<string, any>;
};
declare const TableContext: import("react").Context<{
    uuid: string;
    persistenceType: "online" | "localStorage" | "sessionStorage" | undefined;
    persistenceKey: string | undefined;
    onlineChange: ((key: string, ColumnsState: Record<string, ColumnsState>) => void) | undefined;
    sortKeyColumns: string[];
    setSortKeyColumns: (keys: string[]) => void;
    columnsMap: Record<string, ColumnsState>;
    setColumnsMap: (updater: Record<string, ColumnsState> | ((origin: Record<string, ColumnsState>) => Record<string, ColumnsState>), ignoreDestroy?: boolean | undefined) => void;
    setTableSize: (updater: DensitySize | ((origin: DensitySize) => DensitySize), ignoreDestroy?: boolean | undefined) => void;
    tableSize: DensitySize;
    columns: ProTableColumn<any>[] | undefined;
    clearPersistenceStorage: () => void;
    defaultColumnKeyMap: Record<string, any>;
}>;
export type ContainerType = typeof useContainer;
declare const Container: React.FC<{
    initValue: UseContainerProps<any>;
    children: React.ReactNode;
}>;
export { TableContext };
export default Container;
