import { BitzTableProps } from './Table';
import BitzTableProvider, { TableContext as BitzTableContext, DensitySize as BitzTableSizeType, ProTableColumn } from './Store';
import ActionBar from './ActionBar';
import ToolBar from './ToolBar';
import ActionCol from './ActionCol';
import SelectionBar from './SelectionBar';
import { ReactNode, Ref } from 'react';
/** 操作按钮属性 */
interface Action<T> {
    key?: string;
    icon?: ReactNode;
    label?: string;
    type?: 'divider' | 'detail';
    danger?: boolean;
    onClick?: () => void;
    children?: Action<T>[];
}
/** 按钮操作列属性 */
interface BitzTableActionProps<T> {
    loading?: boolean;
    /**
     * 操作按钮组，主要操作、次要操作、下拉列表(含危险操作)
     * @次要操作 次要操作以下拉菜单显示，如果actionGroup的长度大于3，从第4个开始直到最后的所有按钮都为次要操作按钮
     */
    actionGroup: Action<T>[];
    refInstance?: Ref<HTMLDivElement>;
}
type ActionsFunType<T> = (record: T, index: number) => Action<T>[];
/** ActionCol hook参数 */
interface BitzTableActionColProps<T> extends Omit<BitzTableActionProps<T>, 'refInstance' | 'actionGroup'>, Omit<BitzTableColumnType<T>, 'width' | 'render'> {
    actionGroup: ActionsFunType<T>;
}
interface BitzTableColumnType<RecordType = any> extends ProTableColumn<RecordType> {
    /** 隐藏列 移动端生效 */
    mobileHide?: boolean;
    /** 隐藏label 移动端生效 */
    mobileHideLabel?: boolean;
    /** 是否为操作列 */
    isOperationCol?: boolean;
    /** 列宽根据内容宽度最大的设置(只应用在操作列上) */
    useMaxWidth?: boolean;
}
type BitzTableColumnsType<DataType> = BitzTableColumnType<DataType>[];
type CompoundedComponent = React.ForwardRefExoticComponent<BitzTableProps> & {
    ActionBar: typeof ActionBar;
    ToolBar: typeof ToolBar;
    SelectionBar: typeof SelectionBar;
    ActionCol: typeof ActionCol;
};
declare const BitzTable: CompoundedComponent;
export type { BitzTableProps, BitzTableSizeType, BitzTableColumnType, BitzTableColumnsType, ActionsFunType, Action, BitzTableActionProps, BitzTableActionColProps, };
export { BitzTableProvider, BitzTableContext };
export default BitzTable;
